@@ -22,8 +22,8 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python2.7',
  'COREPYTHONPATH': ':plat-linux2:lib-tk:lib-old',
- 'COVERAGE_INFO': '/build/python2/src/Python-2.7.17/coverage.info',
- 'COVERAGE_REPORT': '/build/python2/src/Python-2.7.17/lcov-report',
+ 'COVERAGE_INFO': '/build/python2/src/Python-2.7.18/coverage.info',
+ 'COVERAGE_REPORT': '/build/python2/src/Python-2.7.18/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov report"',
  'CPPFLAGS': '-I. -IInclude -I./Include -D_FORTIFY_SOURCE=2',
  'CXX': 'g++ -pthread',
@@ -285,7 +285,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_STRFTIME': 1,
  'HAVE_STRINGS_H': 1,
  'HAVE_STRING_H': 1,
- 'HAVE_STROPTS_H': 1,
+ 'HAVE_STROPTS_H': 0,
  'HAVE_STRUCT_STAT_ST_BIRTHTIME': 0,
  'HAVE_STRUCT_STAT_ST_BLKSIZE': 1,
  'HAVE_STRUCT_STAT_ST_BLOCKS': 1,
@@ -377,7 +377,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'LIBC': '',
  'LIBDEST': '/usr/lib/python2.7',
  'LIBDIR': '/usr/lib',
- 'LIBFFI_INCLUDEDIR': '/usr/lib/libffi-3.2.1/include',
+ 'LIBFFI_INCLUDEDIR': '',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
@@ -465,7 +465,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'RANLIB': 'ranlib',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python2/src/Python-2.7.17',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python2/src/Python-2.7.18',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '',
@@ -508,7 +508,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'TESTOPTS': '-l',
  'TESTPATH': '',
  'TESTPROG': './Lib/test/regrtest.py',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python2/src/Python-2.7.17 ./python -Wd -3 -E -tt',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python2/src/Python-2.7.18 ./python -Wd -3 -E -tt',
  'TESTPYTHONOPTS': '',
  'THREADOBJ': 'Python/thread.o',
  'TIME_WITH_SYS_TIME': 1,
@@ -533,8 +533,8 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python2/src/Python-2.7.17',
- 'abs_srcdir': '/build/python2/src/Python-2.7.17',
+ 'abs_builddir': '/build/python2/src/Python-2.7.18',
+ 'abs_srcdir': '/build/python2/src/Python-2.7.18',
  'build': 'aarch64-unknown-linux-gnu',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
